# Help.pm - The Object Class that provides a Help Object
# Created by James A. Pattie, 11/07/2000.

# Copyright (c) 2000-2002 Xperience, Inc. http://www.pcxperience.com/
#
#This program is free software; you can redistribute it and/or
#modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation; either version 2
#of the License, or (at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

package Portal::squidGuard::Data::Help;
use strict;
use vars qw($AUTOLOAD $VERSION @ISA @EXPORT);

require Exporter;

@ISA = qw(Exporter AutoLoader);
@EXPORT = qw();

$VERSION = '0.02';

# Help Data structure
my %Topics = (
             en => {
                     Normal => {
                               "_order_" => "Close App,_seperator_,Refresh,Help,_seperator_,Server Settings,DB Rules",
                               "Close App" => "This closes the squidGuard Administration Application and returns you to the Portal Desktop.",
                               "Refresh" => "This redisplays the list of Black List Groups you are working with and provides links to edit the Domains and Urls files in them.",
                               "Help" => "This is what you are currently seeing.",
                               "Server Settings" => "This module allows you to specify servers you are working with and the Black List groups to display on the Main Menu for each server. &nbsp;You also can specify the password to use when downloading this servers data.",
                               "DB Rules" => {
                                            "_order_" => "Delete,Edit,Update,Export",
                                            "_overview_" => "The Rules module allows you to actually create/edit/delete domains and urls entries in the squidGuard allowed/black lists databases. &nbsp;The allowed entries are everything that makes up the allowed database files, while the black list entries are what needs to be added to the specified black list group. &nbsp;If you need to \"remove\" a blocked site, just add it to the corresponding allowed file (domains or urls) based on what is being blocked (a complete domain or just a specific page).",
                                            "Delete" => "Allows you to delete the specified domains or urls entries.",
                                            "Edit" => "Will copy the selected domains or urls entries to the Update textarea. &nbsp;Click the Update button to update them in the database.",
                                            "Update" => "Use the Update Textarea to add/edit domains or urls. &nbsp;Do not hit &lt;Enter&gt; unless you are starting a new domain or url.<br><br>Url entries are to allow you to allow/block access to a specific section of a site when the entire site is currently blocked/allowed.",
                                            "Export" => "Increments the version number which will enable the firewall to get any changes you've made the next time it queries for an update.",
                                          },
                               },
                     System => {
                               "_order_" => "This should never be reached",
                               "This should never be reached" => "The Portal always runs in Normal mode!<br><br>Go <help app=\"Portal\" content=\"Normal,Help\">here</help> to return to the Normal Help System.",
                               },
                   },
             );

# new
# instantiates an instance of a Help
# takes: lang
sub new
{
  my $that = shift;
  my $class = ref($that) || $that;
  my $self = bless {}, $class;
  my %args = ( lang => "en", @_ );
  my $errStr = "Portal::squidGuard::Data::Help->new() - Error!<br>\n";

  $self->{lang} = $args{lang};  # we will assume this language is valid as the Language module will have already validated it for us.
  $self->{Topics} = \%Topics;   # store the help data in the class.
  if (!exists $self->{Topics}->{$self->{lang}})
  {
    $self->{lang} = "en";  # This must always exist!
  }

  # do validation
  $self->{error} = !$self->isValid;
  if ($self->{error})
  {
    $self->{errorString} = $errStr . $self->{errorString};
  }

  return $self;
}

# isValid - Returns 0 or 1 to indicate if the object is valid.
sub isValid
{
  my $self = shift;
  my $error = 0;
  my $errorString = "";
  my $errStr = "Portal::squidGuard::Data::Help->isValid() - Error!<br>\n";

  # do validation code here.

  if (length $errorString > 0)
  {
    $error = 1;
    $self->{error} = $error;
    $self->{errorString} = $errStr;
    $self->{errorString} .= $errorString;
  }

  return !$error;
}

sub DESTROY
{
  my $self = shift;
}

sub AUTOLOAD
{
  my $self = shift;
  my $type = ref($self) || die "$self is not an object";
  my $name = $AUTOLOAD;
  $name =~ s/.*://;	# strip fully-qualified portion
  unless (exists $self->{$name})
  {
    die "Can't access `$name' field in object of class $type";
  }
  if (@_)
  {
    return $self->{$name} = shift;
  }
  else
  {
    return $self->{$name};
  }
}

# setError
# requires: errorString
# returns: nothing
sub setError
{
  my $self = shift;
  my %args = ( errorString => "", @_ );
  my $errorString = $args{errorString};

  $self->{errorString} = $errorString;
  $self->{error} = 1;
}

# didErrorOccur
# returns the value of error.
sub didErrorOccur
{
  my $self = shift;

  return $self->{error};
}

# errorMessage
# returns the value of errorString
sub errorMessage
{
  my $self = shift;

  return $self->{errorString};
}

1;
__END__

=head1 NAME

Help - Object used to build a Help Object Class.

=head1 SYNOPSIS

  use Portal::squidGuard::Data::Help;
  my $obj = Portal::squidGuard::Data::Help->new;
  if ($obj->didErrorOccur())
  {
    die $obj->errorMessage();
  }

=head1 DESCRIPTION

Help is a Help class.

=head1 Exported FUNCTIONS

  scalar new(lang)
    Creates a new instance of the Portal::squidGuard::Data::Help
    object.

  bool isValid(void)
    Returns 0 or 1 to indicate if the object is valid.  The error will be
    available via errorMessage().
    
  void setError(errorString)
    Sets error = 1 and errorString = errorString.

  scalar didErrorOccur(void)
    Returns the value of error.

  scalar errorMessage(void)
    Returns the value of errorString.

=head1 Exported FUNCTIONS

  Topics - Help topics hash.  The language code is the first index,
           followed by Normal and System.  They provide the main indexes
           for the Normal and System modes.  Under them are the topics
           of interest for the 2 modes.

  NOTE:  All data fields are accessible by specifying the object
         and pointing to the data member to be modified on the
         left-hand side of the assignment.
         Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

PC & Web Xperience, Inc. (mailto:admin@pcxperience.com)

=head1 SEE ALSO

perl(1), Portal(3), Portal::Help(3)

=cut
